@@ -14,19 +14,24 @@
 
 """Fleet API Client for making HTTP requests to Fleet services."""
 
-import asyncio
 import os
 import httpx
 import logging
 from typing import Optional, List
 
-from .base import EnvironmentBase, AsyncWrapper, SyncWrapper
+from .base import EnvironmentBase, SyncWrapper
 from .models import InstanceRequest, InstanceRecord, Environment as EnvironmentModel
 
-from .manager import InstanceClient, AsyncInstanceClient, ResetRequest, ResetResponse
+from .instance import (
+    InstanceClient,
+    ResetRequest,
+    ResetResponse,
+    ValidatorType,
+    ExecuteFunctionResponse,
+)
 from .resources.base import Resource
-from .resources.sqlite import AsyncSQLiteResource
-from .resources.browser import AsyncBrowserResource
+from .resources.sqlite import SQLiteResource
+from .resources.browser import BrowserResource
 
 logger = logging.getLogger(__name__)
 
@@ -34,7 +39,7 @@ logger = logging.getLogger(__name__)
 class Environment(EnvironmentBase):
     def __init__(self, httpx_client: Optional[httpx.Client] = None, **kwargs):
         super().__init__(**kwargs)
-        self._httpx_client = httpx_client or httpx.Client()
+        self._httpx_client = httpx_client or httpx.Client(timeout=60.0)
         self._instance: Optional[InstanceClient] = None
 
     @property
@@ -43,38 +48,33 @@ class Environment(EnvironmentBase):
             self._instance = InstanceClient(self.manager_url, self._httpx_client)
         return self._instance
 
-
-class AsyncEnvironment(EnvironmentBase):
-    def __init__(self, httpx_client: Optional[httpx.AsyncClient] = None, **kwargs):
-        super().__init__(**kwargs)
-        self._httpx_client = httpx_client or httpx.AsyncClient()
-        self._instance: Optional[AsyncInstanceClient] = None
-
-    @property
-    def instance(self) -> AsyncInstanceClient:
-        if self._instance is None:
-            self._instance = AsyncInstanceClient(self.manager_url, self._httpx_client)
-        return self._instance
-
-    async def reset(
+    def reset(
         self, seed: Optional[int] = None, timestamp: Optional[int] = None
     ) -> ResetResponse:
-        return await self.instance.reset(ResetRequest(seed=seed, timestamp=timestamp))
+        return self.instance.reset(ResetRequest(seed=seed, timestamp=timestamp))
 
-    def db(self, name: str = "current") -> AsyncSQLiteResource:
+    def db(self, name: str = "current") -> SQLiteResource:
         return self.instance.db(name)
 
-    def browser(self, name: str = "cdp") -> AsyncBrowserResource:
+    def browser(self, name: str = "cdp") -> BrowserResource:
         return self.instance.browser(name)
 
     def state(self, uri: str) -> Resource:
         return self.instance.state(uri)
 
-    async def resources(self) -> List[Resource]:
-        return await self.instance.resources()
+    def resources(self) -> List[Resource]:
+        return self.instance.resources()
 
-    async def close(self) -> InstanceRecord:
-        return await AsyncFleet().delete(self.instance_id)
+    def close(self) -> InstanceRecord:
+        return Fleet().delete(self.instance_id)
+
+    def verify(self, validator: ValidatorType) -> ExecuteFunctionResponse:
+        return self.instance.verify(validator)
+
+    def verify_raw(
+        self, function_code: str, function_name: str
+    ) -> ExecuteFunctionResponse:
+        return self.instance.verify_raw(function_code, function_name)
 
 
 class Fleet:
@@ -91,7 +91,7 @@ class Fleet:
             httpx_client=self._httpx_client,
         )
 
-    def environments(self) -> List[EnvironmentModel]:
+    def list_envs(self) -> List[EnvironmentModel]:
         response = self.client.request("GET", "/v1/env/")
         return [EnvironmentModel(**env_data) for env_data in response.json()]
 
@@ -99,11 +99,22 @@ class Fleet:
         response = self.client.request("GET", f"/v1/env/{env_key}")
         return EnvironmentModel(**response.json())
 
-    def make(self, request: InstanceRequest) -> Environment:
+    def make(self, env_key: str) -> Environment:
+        if ":" in env_key:
+            env_key_part, version = env_key.split(":", 1)
+            if not version.startswith("v"):
+                version = f"v{version}"
+        else:
+            env_key_part = env_key
+            version = None
+
+        request = InstanceRequest(env_key=env_key_part, version=version)
         response = self.client.request(
             "POST", "/v1/env/instances", json=request.model_dump()
         )
-        return Environment(**response.json())
+        instance = Environment(**response.json())
+        instance.instance.load()
+        return instance
 
     def instances(self, status: Optional[str] = None) -> List[Environment]:
         params = {}
@@ -119,68 +130,4 @@ class Fleet:
 
     def delete(self, instance_id: str) -> InstanceRecord:
         response = self.client.request("DELETE", f"/v1/env/instances/{instance_id}")
-        return InstanceRecord(**response.json())
-
-
-class AsyncFleet:
-    def __init__(
-        self,
-        api_key: Optional[str] = os.getenv("FLEET_API_KEY"),
-        base_url: Optional[str] = None,
-        httpx_client: Optional[httpx.AsyncClient] = None,
-    ):
-        self._httpx_client = httpx_client or httpx.AsyncClient(timeout=60.0)
-        self.client = AsyncWrapper(
-            api_key=api_key,
-            base_url=base_url,
-            httpx_client=self._httpx_client,
-        )
-
-    async def list_envs(self) -> List[EnvironmentModel]:
-        response = await self.client.request("GET", "/v1/env/")
-        return [EnvironmentModel(**env_data) for env_data in response.json()]
-
-    async def environment(self, env_key: str) -> EnvironmentModel:
-        response = await self.client.request("GET", f"/v1/env/{env_key}")
-        return EnvironmentModel(**response.json())
-
-    async def make(self, env_key: str) -> AsyncEnvironment:
-        if ":" in env_key:
-            env_key_part, version = env_key.split(":", 1)
-            if not version.startswith("v"):
-                version = f"v{version}"
-        else:
-            env_key_part = env_key
-            version = None
-
-        request = InstanceRequest(env_key=env_key_part, version=version)
-        response = await self.client.request(
-            "POST", "/v1/env/instances", json=request.model_dump()
-        )
-        instance = AsyncEnvironment(**response.json())
-        await instance.instance.load()
-        return instance
-
-    async def instances(self, status: Optional[str] = None) -> List[AsyncEnvironment]:
-        params = {}
-        if status:
-            params["status"] = status
-
-        response = await self.client.request("GET", "/v1/env/instances", params=params)
-        instances = [
-            AsyncEnvironment(**instance_data) for instance_data in response.json()
-        ]
-        await asyncio.gather(*[instance.instance.load() for instance in instances])
-        return instances
-
-    async def instance(self, instance_id: str) -> AsyncEnvironment:
-        response = await self.client.request("GET", f"/v1/env/instances/{instance_id}")
-        instance = AsyncEnvironment(**response.json())
-        await instance.env.load()
-        return instance
-
-    async def delete(self, instance_id: str) -> InstanceRecord:
-        response = await self.client.request(
-            "DELETE", f"/v1/env/instances/{instance_id}"
-        )
-        return InstanceRecord(**response.json())
+        return InstanceRecord(**response.json())
\ No newline at end of file
